@@ -6,6 +6,7 @@ import docutils.nodes as nodes
 from sphinx.application import Sphinx
 
 from .descriptionparser import get_description
+from .metaparser import get_meta_description
 from .titleparser import get_title
 
 import os
@@ -28,10 +29,10 @@ IMAGE_MIME_TYPES = {
 }
 
 
-def make_tag(property: str, content: str) -> str:
+def make_tag(property: str, content: str, type_: str = "property") -> str:
     # Parse quotation, so they won't break html tags if smart quotes are disabled
     content = content.replace('"', "&quot;")
-    return f'<meta property="{property}" content="{content}" />\n  '
+    return f'<meta {type_}="{property}" content="{content}" />'
 
 
 def get_tags(
@@ -45,6 +46,7 @@ def get_tags(
     if fields is None:
         fields = {}
     tags = {}
+    meta_tags = {}  # For non-og meta tags
 
     # Set length of description
     try:
@@ -72,7 +74,7 @@ def get_tags(
         parse_result = urlparse(config["html_baseurl"])
 
         if config["html_baseurl"] is None:
-            raise EnvironmentError("ReadTheDocs did not provide a valid canonical URL!")
+            raise OSError("ReadTheDocs did not provide a valid canonical URL!")
 
         # Grab root url from canonical url
         config["ogp_site_url"] = urlunparse(
@@ -89,7 +91,13 @@ def get_tags(
     # url tag
     # Get the URL of the specific page
     if context["builder"] == "dirhtml":
-        page_url = urljoin(config["ogp_site_url"], context["pagename"] + "/")
+        if context["pagename"] == "index":
+            page_url = config["ogp_site_url"]
+        elif context["pagename"].endswith("/index"):
+            relative = context["pagename"].rsplit("/", 1)[0]
+            page_url = urljoin(config["ogp_site_url"], relative + "/")
+        else:
+            page_url = urljoin(config["ogp_site_url"], context["pagename"] + "/")
     else:
         page_url = urljoin(
             config["ogp_site_url"], context["pagename"] + context["file_suffix"]
@@ -105,6 +113,11 @@ def get_tags(
     if description:
         tags["og:description"] = description
 
+        if config["ogp_enable_meta_description"] and not get_meta_description(
+            context["metatags"]
+        ):
+            meta_tags["description"] = description
+
     # image tag
     # Get basic values from config
     if "og:image" in fields:
@@ -158,8 +171,13 @@ def get_tags(
     # arbitrary tags and overrides
     tags.update({k: v for k, v in fields.items() if k.startswith("og:")})
 
-    return "\n" + "\n".join(
-        [make_tag(p, c) for p, c in tags.items()] + config["ogp_custom_meta_tags"]
+    return (
+        "\n".join(
+            [make_tag(p, c) for p, c in tags.items()]
+            + [make_tag(p, c, "name") for p, c in meta_tags.items()]
+            + config["ogp_custom_meta_tags"]
+        )
+        + "\n"
     )
 
 
@@ -183,6 +201,7 @@ def setup(app: Sphinx) -> Dict[str, Any]:
     app.add_config_value("ogp_type", "website", "html")
     app.add_config_value("ogp_site_name", None, "html")
     app.add_config_value("ogp_custom_meta_tags", [], "html")
+    app.add_config_value("ogp_enable_meta_description", True, "html")
 
     app.connect("html-page-context", html_page_context)
 
